aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorHailong Wen <youxiabsyw@gmail.com>2018-01-22 14:18:36 -0800
committerGitHub <noreply@github.com>2018-01-22 14:18:36 -0800
commite9b6178dce0dd70e5ba600ba331f50aaa567ce60 (patch)
tree5facc796622a0de3558d74a0f4d05349208aeb0a
parentd18ff00b33537dc402e22efaf1547f3733293594 (diff)
downloadopencensus-java-e9b6178dce0dd70e5ba600ba331f50aaa567ce60.tar.gz
Update script in RELEASING.md and use them to update release version in all readmes and build files. (fixes #941) (#946)
-rw-r--r--README.md12
-rw-r--r--RELEASING.md81
-rw-r--r--contrib/grpc_util/README.md4
-rw-r--r--contrib/zpages/README.md12
-rw-r--r--examples/build.gradle2
-rw-r--r--examples/opencensus_workspace.bzl78
-rw-r--r--examples/pom.xml2
-rw-r--r--exporters/stats/signalfx/README.md12
-rw-r--r--exporters/stats/stackdriver/README.md14
-rw-r--r--exporters/trace/logging/README.md12
-rw-r--r--exporters/trace/stackdriver/README.md12
-rw-r--r--exporters/trace/zipkin/README.md12
12 files changed, 170 insertions, 83 deletions
diff --git a/README.md b/README.md
index 69f680a8..095047a2 100644
--- a/README.md
+++ b/README.md
@@ -27,14 +27,14 @@ For Maven add to your `pom.xml`:
<dependency>
<groupId>io.opencensus</groupId>
<artifactId>opencensus-api</artifactId>
- <version>0.10.1</version>
+ <version>0.11.0</version>
</dependency>
</dependencies>
```
For Gradle add to your dependencies:
```gradle
-compile 'io.opencensus:opencensus-api:0.10.1'
+compile 'io.opencensus:opencensus-api:0.11.0'
```
### Hello "OpenCensus" trace events
@@ -85,12 +85,12 @@ For Maven add to your `pom.xml`:
<dependency>
<groupId>io.opencensus</groupId>
<artifactId>opencensus-api</artifactId>
- <version>0.10.1</version>
+ <version>0.11.0</version>
</dependency>
<dependency>
<groupId>io.opencensus</groupId>
<artifactId>opencensus-impl</artifactId>
- <version>0.10.1</version>
+ <version>0.11.0</version>
<scope>runtime</scope>
</dependency>
</dependencies>
@@ -98,8 +98,8 @@ For Maven add to your `pom.xml`:
For Gradle add to your dependencies:
```gradle
-compile 'io.opencensus:opencensus-api:0.10.1'
-runtime 'io.opencensus:opencensus-impl:0.10.1'
+compile 'io.opencensus:opencensus-api:0.11.0'
+runtime 'io.opencensus:opencensus-impl:0.11.0'
```
### How to setup exporters?
diff --git a/RELEASING.md b/RELEASING.md
index 195bb3d7..9067de65 100644
--- a/RELEASING.md
+++ b/RELEASING.md
@@ -190,6 +190,87 @@ Central (the staging repository will be destroyed in the process). You can see
the complete process for releasing to Maven Central on the [OSSRH
site](http://central.sonatype.org/pages/releasing-the-deployment.html).
+## Announcement
+
+Once deployment is done, go to Github [release
+page](https://github.com/census-instrumentation/opencensus-java/releases), press
+`Draft a new release` to write release notes about the new release.
+
+You can use `git log upstream/v$MAJOR.$((MINOR-1)).x..upstream/v$MAJOR.$MINOR.x --graph --first-parent`
+or the Github [compare tool](https://github.com/census-instrumentation/opencensus-java/compare/)
+to view a summary of all commits since last release as a reference.
+Please pick major or important user-visible changes only.
+
+## Update release versions in documentations and build files
+
+After releasing is done, you need to update all readmes and examples to point to the
+latest version.
+
+1. Update README.md and gradle/maven build files on `master` branch:
+
+```bash
+$ git checkout -b bump-document-version master
+$ BUILD_FILES=(
+ examples/build.gradle
+ examples/pom.xml
+ )
+$ README_FILES=(
+ README.md
+ contrib/grpc_util/README.md
+ contrib/http_util/README.md
+ contrib/zpages/README.md
+ exporters/stats/signalfx/README.md
+ exporters/stats/stackdriver/README.md
+ exporters/trace/logging/README.md
+ exporters/trace/stackdriver/README.md
+ exporters/trace/zipkin/README.md
+ )
+# Substitute versions in build files
+$ sed -i 's/[0-9]\+\.[0-9]\+\.[0-9]\+\(.*LATEST_OPENCENSUS_RELEASE_VERSION\)/'$MAJOR.$MINOR.$PATCH'\1/' \
+ "${BUILD_FILES[@]}"
+# Substitute versions in build.gradle examples in README.md
+$ sed -i 's/\(\(compile\|runtime\).\+io\.opencensus:.\+:\)[0-9]\+\.[0-9]\+\.[0-9]\+/\1'$MAJOR.$MINOR.$PATCH'/' \
+ "${README_FILES[@]}"
+# Substitute versions in maven pom examples in README.md
+$ sed -i 's/\(<version>\)[0-9]\+\.[0-9]\+\.[0-9]\+/\1'$MAJOR.$MINOR.$PATCH'/' \
+ "${README_FILES[@]}"
+```
+
+2. Update bazel dependencies for subproject `examples`:
+
+ - Follow the instructions on [this
+ page](https://docs.bazel.build/versions/master/generate-workspace.html) to
+ install bazel migration tool. You may also need to manually apply
+ this [patch](
+ https://github.com/nevillelyh/migration-tooling/commit/f10e14fd18ad3885c7ec8aa305e4eba266a07ebf)
+ if you encounter `Unable to find a version for ... due to Invalid Range Result` error when
+ using it.
+
+ - Use the following command to generate new dependencies file:
+
+ ```bash
+ $ bazel run //generate_workspace -- \
+ --artifact=io.opencensus:opencensus-api:$MAJOR.$MINOR.$PATCH \
+ --artifact=io.opencensus:opencensus-contrib-zpages:$MAJOR.$MINOR.$PATCH \
+ --artifact=io.opencensus:opencensus-exporter-trace-logging:$MAJOR.$MINOR.$PATCH \
+ --artifact=io.opencensus:opencensus-impl:$MAJOR.$MINOR.$PATCH \
+ --repositories=http://repo.maven.apache.org/maven2
+ Wrote
+ /usr/local/.../generate_workspace.runfiles/__main__/generate_workspace.bzl
+ ```
+
+ - Copy this file to overwrite `examples/opencensus_workspace.bzl`.
+
+ - Use the following command to rename the generated rules and commit the
+ changes above:
+
+ ```bash
+ $ sed -i 's/def generated_/def opencensus_/' examples/opencensus_workspace.bzl
+ $ git commit -a -m "Update release versions for all readme and build files."
+ ```
+
+3. Go through PR review and merge it to GitHub master branch.
+
## Known Issues
### Deployment for tag v0.5.0
diff --git a/contrib/grpc_util/README.md b/contrib/grpc_util/README.md
index daa82f37..1208662c 100644
--- a/contrib/grpc_util/README.md
+++ b/contrib/grpc_util/README.md
@@ -16,14 +16,14 @@ For Maven add to your `pom.xml`:
<dependency>
<groupId>io.opencensus</groupId>
<artifactId>opencensus-contrib-grpc-util</artifactId>
- <version>0.10.1</version>
+ <version>0.11.0</version>
</dependency>
</dependencies>
```
For Gradle add to your dependencies:
```gradle
-compile 'io.opencensus:opencensus-contrib-grpc-util:0.10.1'
+compile 'io.opencensus:opencensus-contrib-grpc-util:0.11.0'
```
[travis-image]: https://travis-ci.org/census-instrumentation/opencensus-java.svg?branch=master
diff --git a/contrib/zpages/README.md b/contrib/zpages/README.md
index 4917deed..135d3648 100644
--- a/contrib/zpages/README.md
+++ b/contrib/zpages/README.md
@@ -16,17 +16,17 @@ For Maven add to your `pom.xml`:
<dependency>
<groupId>io.opencensus</groupId>
<artifactId>opencensus-api</artifactId>
- <version>0.10.1</version>
+ <version>0.11.0</version>
</dependency>
<dependency>
<groupId>io.opencensus</groupId>
<artifactId>opencensus-contrib-zpages</artifactId>
- <version>0.10.1</version>
+ <version>0.11.0</version>
</dependency>
<dependency>
<groupId>io.opencensus</groupId>
<artifactId>opencensus-impl</artifactId>
- <version>0.10.1</version>
+ <version>0.11.0</version>
<scope>runtime</scope>
</dependency>
</dependencies>
@@ -34,9 +34,9 @@ For Maven add to your `pom.xml`:
For Gradle add to your dependencies:
```gradle
-compile 'io.opencensus:opencensus-api:0.10.1'
-compile 'io.opencensus:opencensus-contrib-zpages:0.10.1'
-runtime 'io.opencensus:opencensus-impl:0.10.1'
+compile 'io.opencensus:opencensus-api:0.11.0'
+compile 'io.opencensus:opencensus-contrib-zpages:0.11.0'
+runtime 'io.opencensus:opencensus-impl:0.11.0'
```
### Register the Z-Pages
diff --git a/examples/build.gradle b/examples/build.gradle
index 75bd3bbf..9acb5f25 100644
--- a/examples/build.gradle
+++ b/examples/build.gradle
@@ -12,7 +12,7 @@ repositories {
group = "io.opencensus"
version = "0.12.0-SNAPSHOT" // CURRENT_OPENCENSUS_VERSION
-def opencensusVersion = "0.10.1" // LATEST_OPENCENSUS_RELEASE_VERSION
+def opencensusVersion = "0.11.0" // LATEST_OPENCENSUS_RELEASE_VERSION
checkstyle {
configFile = file("$rootDir/../buildscripts/checkstyle.xml")
diff --git a/examples/pom.xml b/examples/pom.xml
index a35484f8..8fc1f540 100644
--- a/examples/pom.xml
+++ b/examples/pom.xml
@@ -10,7 +10,7 @@
<properties>
<project.build.sourceEncoding>UTF-8</project.build.sourceEncoding>
<!-- change to the version you want to use. -->
- <opencensus.version>0.10.1</opencensus.version><!-- LATEST_OPENCENSUS_VERSION -->
+ <opencensus.version>0.11.0</opencensus.version><!-- LATEST_OPENCENSUS_RELEASE_VERSION -->
</properties>
<dependencies>
<dependency>
diff --git a/exporters/stats/signalfx/README.md b/exporters/stats/signalfx/README.md
index 8c4defb1..e4bedef6 100644
--- a/exporters/stats/signalfx/README.md
+++ b/exporters/stats/signalfx/README.md
@@ -27,17 +27,17 @@ For Maven add to your `pom.xml`:
<dependency>
<groupId>io.opencensus</groupId>
<artifactId>opencensus-api</artifactId>
- <version>0.10.1</version>
+ <version>0.11.0</version>
</dependency>
<dependency>
<groupId>io.opencensus</groupId>
<artifactId>opencensus-exporter-stats-signalfx</artifactId>
- <version>0.10.1</version>
+ <version>0.11.0</version>
</dependency>
<dependency>
<groupId>io.opencensus</groupId>
<artifactId>opencensus-impl</artifactId>
- <version>0.10.1</version>
+ <version>0.11.0</version>
<scope>runtime</scope>
</dependency>
</dependencies>
@@ -46,9 +46,9 @@ For Maven add to your `pom.xml`:
For Gradle add to your dependencies:
```
-compile 'io.opencensus:opencensus-api:0.10.1'
-compile 'io.opencensus:opencensus-exporter-stats-signalfx:0.10.1'
-runtime 'io.opencensus:opencensus-impl:0.10.1'
+compile 'io.opencensus:opencensus-api:0.11.0'
+compile 'io.opencensus:opencensus-exporter-stats-signalfx:0.11.0'
+runtime 'io.opencensus:opencensus-impl:0.11.0'
```
### Register the exporter
diff --git a/exporters/stats/stackdriver/README.md b/exporters/stats/stackdriver/README.md
index ef3eaacc..470cc6c5 100644
--- a/exporters/stats/stackdriver/README.md
+++ b/exporters/stats/stackdriver/README.md
@@ -31,17 +31,17 @@ For Maven add to your `pom.xml`:
<dependency>
<groupId>io.opencensus</groupId>
<artifactId>opencensus-api</artifactId>
- <version>0.10.1</version>
+ <version>0.11.0</version>
</dependency>
<dependency>
<groupId>io.opencensus</groupId>
<artifactId>opencensus-exporter-stats-stackdriver</artifactId>
- <version>0.10.1</version>
+ <version>0.11.0</version>
</dependency>
<dependency>
<groupId>io.opencensus</groupId>
<artifactId>opencensus-impl</artifactId>
- <version>0.10.1</version>
+ <version>0.11.0</version>
<scope>runtime</scope>
</dependency>
</dependencies>
@@ -49,9 +49,9 @@ For Maven add to your `pom.xml`:
For Gradle add to your dependencies:
```groovy
-compile 'io.opencensus:opencensus-api:0.10.1'
-compile 'io.opencensus:opencensus-exporter-stats-stackdriver:0.10.1'
-runtime 'io.opencensus:opencensus-impl:0.10.1'
+compile 'io.opencensus:opencensus-api:0.11.0'
+compile 'io.opencensus:opencensus-exporter-stats-stackdriver:0.11.0'
+runtime 'io.opencensus:opencensus-impl:0.11.0'
```
#### Register the exporter
@@ -147,4 +147,4 @@ Stackdriver exporter adds a new `Metric` label for each custom `Metric` to ensur
of the `Timeseries`. The format of the label is: `{LANGUAGE}-{PID}@{HOSTNAME}`, if `{PID}` is not
available a random number will be used.
-[stackdriver-monitoring]: https://cloud.google.com/monitoring/ \ No newline at end of file
+[stackdriver-monitoring]: https://cloud.google.com/monitoring/
diff --git a/exporters/trace/logging/README.md b/exporters/trace/logging/README.md
index 7d48fa7d..6ef59a61 100644
--- a/exporters/trace/logging/README.md
+++ b/exporters/trace/logging/README.md
@@ -15,17 +15,17 @@ For Maven add to your `pom.xml`:
<dependency>
<groupId>io.opencensus</groupId>
<artifactId>opencensus-api</artifactId>
- <version>0.10.1</version>
+ <version>0.11.0</version>
</dependency>
<dependency>
<groupId>io.opencensus</groupId>
<artifactId>opencensus-exporter-trace-logging</artifactId>
- <version>0.10.1</version>
+ <version>0.11.0</version>
</dependency>
<dependency>
<groupId>io.opencensus</groupId>
<artifactId>opencensus-impl</artifactId>
- <version>0.10.1</version>
+ <version>0.11.0</version>
<scope>runtime</scope>
</dependency>
</dependencies>
@@ -33,9 +33,9 @@ For Maven add to your `pom.xml`:
For Gradle add to your dependencies:
```gradle
-compile 'io.opencensus:opencensus-api:0.10.1'
-compile 'io.opencensus:opencensus-exporter-trace-logging:0.10.1'
-runtime 'io.opencensus:opencensus-impl:0.10.1'
+compile 'io.opencensus:opencensus-api:0.11.0'
+compile 'io.opencensus:opencensus-exporter-trace-logging:0.11.0'
+runtime 'io.opencensus:opencensus-impl:0.11.0'
```
### Register the exporter
diff --git a/exporters/trace/stackdriver/README.md b/exporters/trace/stackdriver/README.md
index 292b0846..71cdaf5f 100644
--- a/exporters/trace/stackdriver/README.md
+++ b/exporters/trace/stackdriver/README.md
@@ -34,17 +34,17 @@ For Maven add to your `pom.xml`:
<dependency>
<groupId>io.opencensus</groupId>
<artifactId>opencensus-api</artifactId>
- <version>0.10.1</version>
+ <version>0.11.0</version>
</dependency>
<dependency>
<groupId>io.opencensus</groupId>
<artifactId>opencensus-exporter-trace-stackdriver</artifactId>
- <version>0.10.1</version>
+ <version>0.11.0</version>
</dependency>
<dependency>
<groupId>io.opencensus</groupId>
<artifactId>opencensus-impl</artifactId>
- <version>0.10.1</version>
+ <version>0.11.0</version>
<scope>runtime</scope>
</dependency>
</dependencies>
@@ -52,9 +52,9 @@ For Maven add to your `pom.xml`:
For Gradle add to your dependencies:
```groovy
-compile 'io.opencensus:opencensus-api:0.10.1'
-compile 'io.opencensus:opencensus-exporter-trace-stackdriver:0.10.1'
-runtime 'io.opencensus:opencensus-impl:0.10.1'
+compile 'io.opencensus:opencensus-api:0.11.0'
+compile 'io.opencensus:opencensus-exporter-trace-stackdriver:0.11.0'
+runtime 'io.opencensus:opencensus-impl:0.11.0'
```
#### Register the exporter
diff --git a/exporters/trace/zipkin/README.md b/exporters/trace/zipkin/README.md
index 84a8e1a0..0514c917 100644
--- a/exporters/trace/zipkin/README.md
+++ b/exporters/trace/zipkin/README.md
@@ -33,17 +33,17 @@ For Maven add to your `pom.xml`:
<dependency>
<groupId>io.opencensus</groupId>
<artifactId>opencensus-api</artifactId>
- <version>0.10.1</version>
+ <version>0.11.0</version>
</dependency>
<dependency>
<groupId>io.opencensus</groupId>
<artifactId>opencensus-exporter-trace-zipkin</artifactId>
- <version>0.10.1</version>
+ <version>0.11.0</version>
</dependency>
<dependency>
<groupId>io.opencensus</groupId>
<artifactId>opencensus-impl</artifactId>
- <version>0.10.1</version>
+ <version>0.11.0</version>
<scope>runtime</scope>
</dependency>
</dependencies>
@@ -51,9 +51,9 @@ For Maven add to your `pom.xml`:
For Gradle add to your dependencies:
```groovy
-compile 'io.opencensus:opencensus-api:0.10.1'
-compile 'io.opencensus:opencensus-exporter-trace-zipkin:0.10.1'
-runtime 'io.opencensus:opencensus-impl:0.10.1'
+compile 'io.opencensus:opencensus-api:0.11.0'
+compile 'io.opencensus:opencensus-exporter-trace-zipkin:0.11.0'
+runtime 'io.opencensus:opencensus-impl:0.11.0'
```
#### Register the exporter
diff --git a/examples/opencensus_workspace.bzl b/examples/opencensus_workspace.bzl
index b2b9251a..658a3ca1 100644
--- a/examples/opencensus_workspace.bzl
+++ b/examples/opencensus_workspace.bzl
@@ -1,13 +1,14 @@
# The following dependencies were calculated from:
#
-# generate_workspace --artifact=io.opencensus:opencensus-api:0.10.1 --artifact=io.opencensus:opencensus-contrib-zpages:0.10.1 --artifact=io.opencensus:opencensus-exporter-trace-logging:0.10.1 --artifact=io.opencensus:opencensus-impl:0.10.1 --repositories=http://repo.maven.apache.org/maven2
+# generate_workspace --artifact=io.opencensus:opencensus-api:0.11.0 --artifact=io.opencensus:opencensus-contrib-zpages:0.11.0 --artifact=io.opencensus:opencensus-exporter-trace-logging:0.11.0 --artifact=io.opencensus:opencensus-impl:0.11.0 --repositories=http://repo.maven.apache.org/maven2
+
def opencensus_maven_jars():
# io.opencensus:opencensus-contrib-zpages:jar:0.10.1 got requested version
# io.opencensus:opencensus-impl-core:jar:0.10.1 got requested version
# io.opencensus:opencensus-exporter-trace-logging:jar:0.10.1 got requested version
# io.opencensus:opencensus-impl:jar:0.10.1 got requested version
# io.opencensus:opencensus-api:jar:0.10.1
native.maven_jar(
name = "com_google_code_findbugs_jsr305",
artifact = "com.google.code.findbugs:jsr305:3.0.1",
@@ -16,45 +17,45 @@ def opencensus_maven_jars():
)
- # io.opencensus:opencensus-api:jar:0.10.1
+ # io.opencensus:opencensus-api:jar:0.11.0
native.maven_jar(
name = "io_grpc_grpc_context",
- artifact = "io.grpc:grpc-context:1.8.0",
+ artifact = "io.grpc:grpc-context:1.9.0",
repository = "http://repo.maven.apache.org/maven2/",
- sha1 = "7fe8214b8d1141afadbe0bcad751df2b8fe2e078",
+ sha1 = "28b0836f48c9705abf73829bbc536dba29a1329a",
)
native.maven_jar(
name = "io_opencensus_opencensus_exporter_trace_logging",
- artifact = "io.opencensus:opencensus-exporter-trace-logging:0.10.1",
+ artifact = "io.opencensus:opencensus-exporter-trace-logging:0.11.0",
repository = "http://repo.maven.apache.org/maven2/",
- sha1 = "c9d934614bb0237a39eda79d52d245626ef32d71",
+ sha1 = "6b1b2acffe57e5a5a5235f6a6375deb0e6931b10",
)
# io.opencensus:opencensus-contrib-zpages:jar:0.10.1 got requested version
# io.opencensus:opencensus-impl-core:jar:0.10.1 got requested version
# io.opencensus:opencensus-exporter-trace-logging:jar:0.10.1 got requested version
# io.opencensus:opencensus-impl:jar:0.10.1 got requested version
# io.opencensus:opencensus-api:jar:0.10.1
native.maven_jar(
name = "com_google_errorprone_error_prone_annotations",
- artifact = "com.google.errorprone:error_prone_annotations:2.1.2",
+ artifact = "com.google.errorprone:error_prone_annotations:2.2.0",
repository = "http://repo.maven.apache.org/maven2/",
- sha1 = "6dcc08f90f678ac33e5ef78c3c752b6f59e63e0c",
+ sha1 = "88e3c593e9b3586e1c6177f89267da6fc6986f0c",
)
native.maven_jar(
name = "io_opencensus_opencensus_contrib_zpages",
- artifact = "io.opencensus:opencensus-contrib-zpages:0.10.1",
+ artifact = "io.opencensus:opencensus-contrib-zpages:0.11.0",
repository = "http://repo.maven.apache.org/maven2/",
- sha1 = "4e2cf2a5f05bffb8dedbc8f183f127cd46cd4a3f",
+ sha1 = "e741acc339ee98e5e6f270c6706ad68aeef359a7",
)
- # io.opencensus:opencensus-impl:jar:0.10.1
+ # io.opencensus:opencensus-impl:jar:0.11.0
native.maven_jar(
name = "com_lmax_disruptor",
artifact = "com.lmax:disruptor:3.3.6",
@@ -63,10 +64,10 @@ def opencensus_maven_jars():
)
# io.opencensus:opencensus-contrib-zpages:jar:0.10.1 got requested version
# io.opencensus:opencensus-impl-core:jar:0.10.1 got requested version
# io.opencensus:opencensus-exporter-trace-logging:jar:0.10.1 got requested version
# io.opencensus:opencensus-api:jar:0.10.1
native.maven_jar(
name = "com_google_guava_guava",
artifact = "com.google.guava:guava:19.0",
@@ -75,34 +76,37 @@ def opencensus_maven_jars():
)
# io.opencensus:opencensus-contrib-zpages:jar:0.10.1 got requested version
# io.opencensus:opencensus-impl-core:jar:0.10.1 got requested version
# io.opencensus:opencensus-exporter-trace-logging:jar:0.10.1 got requested version
# io.opencensus:opencensus-impl:jar:0.10.1 got requested version
native.maven_jar(
name = "io_opencensus_opencensus_api",
- artifact = "io.opencensus:opencensus-api:0.10.1",
+ artifact = "io.opencensus:opencensus-api:0.11.0",
repository = "http://repo.maven.apache.org/maven2/",
- sha1 = "1f5319c45aa3f4c879805f2a323d1ab6ba42e334",
+ sha1 = "c1ff1f0d737a689d900a3e2113ddc29847188c64",
)
- # io.opencensus:opencensus-impl:jar:0.10.1
+ # io.opencensus:opencensus-impl:jar:0.11.0
native.maven_jar(
name = "io_opencensus_opencensus_impl_core",
- artifact = "io.opencensus:opencensus-impl-core:0.10.1",
+ artifact = "io.opencensus:opencensus-impl-core:0.11.0",
repository = "http://repo.maven.apache.org/maven2/",
- sha1 = "66b221c4388e3208000422954b4ba0248f7746ca",
+ sha1 = "65cd9fecf9ee0cce6122466c8be8323c2ea93e72",
)
native.maven_jar(
name = "io_opencensus_opencensus_impl",
- artifact = "io.opencensus:opencensus-impl:0.10.1",
+ artifact = "io.opencensus:opencensus-impl:0.11.0",
repository = "http://repo.maven.apache.org/maven2/",
- sha1 = "6a96e07455946d43608a9bde4ed0663cd7c0fe56",
+ sha1 = "2f2b0d13193d9213e99bb51ec68ab62340415646",
)
+
+
+
def opencensus_java_libraries():
native.java_library(
name = "com_google_code_findbugs_jsr305",
@@ -204,3 +208,5 @@ def opencensus_java_libraries():
":io_opencensus_opencensus_impl_core",
],
)
+
+
@@ -1,13 +1,14 @@
def opencensus_maven_jars():
- # io.opencensus:opencensus-contrib-zpages:jar:0.10.1 got requested version
- # io.opencensus:opencensus-impl-core:jar:0.10.1 got requested version
- # io.opencensus:opencensus-exporter-trace-logging:jar:0.10.1 got requested version
- # io.opencensus:opencensus-impl:jar:0.10.1 got requested version
- # io.opencensus:opencensus-api:jar:0.10.1
+ # io.opencensus:opencensus-impl-core:jar:0.11.0 got requested version
+ # io.opencensus:opencensus-contrib-zpages:jar:0.11.0 got requested version
+ # io.opencensus:opencensus-impl:jar:0.11.0 got requested version
+ # io.opencensus:opencensus-exporter-trace-logging:jar:0.11.0 got requested version
+ # io.opencensus:opencensus-api:jar:0.11.0
native.maven_jar(
name = "com_google_code_findbugs_jsr305",
@@ -16,45 +17,45 @@ def opencensus_maven_jars():
)
- # io.opencensus:opencensus-contrib-zpages:jar:0.10.1 got requested version
- # io.opencensus:opencensus-impl-core:jar:0.10.1 got requested version
- # io.opencensus:opencensus-exporter-trace-logging:jar:0.10.1 got requested version
- # io.opencensus:opencensus-impl:jar:0.10.1 got requested version
- # io.opencensus:opencensus-api:jar:0.10.1
+ # io.opencensus:opencensus-impl-core:jar:0.11.0 got requested version
+ # io.opencensus:opencensus-contrib-zpages:jar:0.11.0 got requested version
+ # io.opencensus:opencensus-impl:jar:0.11.0 got requested version
+ # io.opencensus:opencensus-exporter-trace-logging:jar:0.11.0 got requested version
+ # io.opencensus:opencensus-api:jar:0.11.0
native.maven_jar(
name = "com_google_errorprone_error_prone_annotations",
@@ -63,10 +64,10 @@ def opencensus_maven_jars():
)
- # io.opencensus:opencensus-contrib-zpages:jar:0.10.1 got requested version
- # io.opencensus:opencensus-impl-core:jar:0.10.1 got requested version
- # io.opencensus:opencensus-exporter-trace-logging:jar:0.10.1 got requested version
- # io.opencensus:opencensus-api:jar:0.10.1
+ # io.opencensus:opencensus-impl-core:jar:0.11.0 got requested version
+ # io.opencensus:opencensus-contrib-zpages:jar:0.11.0 got requested version
+ # io.opencensus:opencensus-exporter-trace-logging:jar:0.11.0 got requested version
+ # io.opencensus:opencensus-api:jar:0.11.0
native.maven_jar(
name = "com_google_guava_guava",
@@ -75,34 +76,37 @@ def opencensus_maven_jars():
)
- # io.opencensus:opencensus-contrib-zpages:jar:0.10.1 got requested version
- # io.opencensus:opencensus-impl-core:jar:0.10.1 got requested version
- # io.opencensus:opencensus-exporter-trace-logging:jar:0.10.1 got requested version
- # io.opencensus:opencensus-impl:jar:0.10.1 got requested version
+ # io.opencensus:opencensus-impl-core:jar:0.11.0 got requested version
+ # io.opencensus:opencensus-contrib-zpages:jar:0.11.0 got requested version
+ # io.opencensus:opencensus-impl:jar:0.11.0 got requested version
+ # io.opencensus:opencensus-exporter-trace-logging:jar:0.11.0 got requested version
native.maven_jar(
name = "io_opencensus_opencensus_api",